from fastapi import APIRouter, Depends, status
from sqlalchemy.orm import Session

from app.db.session import get_db

router = APIRouter()


@router.get("/health", status_code=status.HTTP_200_OK)
def health_check(db: Session = Depends(get_db)):
    """
    Health check endpoint.
    """
    try:
        # Check database connection
        db.execute("SELECT 1")
        return {
            "status": "ok",
            "message": "Service is running"
        }
    except Exception as e:
        return {
            "status": "error",
            "message": f"Service is experiencing issues: {str(e)}"
        }